"""Manage API key validation for FastAPI routes."""

from fastapi import Depends, HTTPException, status
from fastapi.security.api_key import APIKeyHeader

from gso.settings import load_oss_params

API_KEY_NAME = "access_token"
api_key_header = APIKeyHeader(name=API_KEY_NAME, auto_error=True)


async def get_api_key(api_key: str = Depends(api_key_header)) -> str:
    """Validate the provided API key against known third-party keys and returns it if valid, else raises HTTP 403."""
    settings = load_oss_params()

    # TODO: This is a simulated database of API keys which should be replace with a real one
    if api_key in settings.THIRD_PARTY_API_KEYS.values():
        return api_key

    raise HTTPException(status_code=status.HTTP_403_FORBIDDEN, detail="Invalid API Key")
